# group-center-client

Group Center(https://github.com/a645162/group-center) Client

## Install

```bash
pip install li-group-center -i https://pypi.python.org/simple
```

```bash
pip install li-group-center==1.3.2 -i https://pypi.python.org/simple
```

## Upgrade

```bash
pip install --upgrade li-group-center -i https://pypi.python.org/simple
```

## Feature

### Machine User Message

```python
from group_center.user_tools import *

# Auto Get Current User Name 
push_message("Test Message~")

# Or
push_message("Test Message~", "konghaomin")
```
